@@ -39,9 +39,9 @@ var LEmail = document.getElementById('pi_email2');
 
 //document.getElementById('client_head').innerHTML = client_name;
 document.getElementsByClassName('headliner')[0].removeAttribute('key');
-document.getElementsByClassName('headliner')[0].innerHTML = client_name;
-Nname.innerHTML =  client_forenames;
-Vname.innerHTML =  client_surename;
+document.getElementsByClassName('headliner')[0].innerHTML = `${client_forenames} ${client_surename}`;
+Nname.innerHTML =  client_surename;
+Vname.innerHTML =  client_forenames;
 Email.innerHTML =  client_mail;
 document.getElementById('pi_id').innerHTML = client_id;
 document.getElementById('pi_fc').innerHTML = client_fc.split(' ')[0];
@@ -49,7 +49,7 @@ document.getElementById('pi_fc').innerHTML = client_fc.split(' ')[0];
 /* The `newElement` function is being called with several arguments to create a new HTML element and
 append it to the element with the ID `pi_newSession`. */
 document.getElementById("pi_newSession").setAttribute('onclick',`new_session_id(${client_id})`)
-newElement({element:"button",cls:['quad-35','uk-button','uk-button-primary','mdi','mdi-24px','mdi-bike','uk-button-small'],attr:[['key-title','cli_new_session'],['style','padding-left:2px'],['onclick',`new_session_id(${client_id})`]]},document.getElementById('pi_newSession'))
+newElement({element:"button",cls:['quad-35','uk-button','uk-button-primary','mdi','mdi-24px','mdi-new-box','uk-button-small'],attr:[['key-title','cli_new_session'],['onclick',`new_session_id(${client_id})`]]},document.getElementById('pi_newSession'))
 
 gen_session_list()
 
@@ -122,7 +122,7 @@ var cli_edit = document.getElementById('cli_edit')
 function editData() {
   if(Nname.childElementCount===0){
   cli_edit.setAttribute('key-title','cli_edit_save')
-  cli_edit.classList.remove('mdi-content-save-edit')
+  cli_edit.classList.remove('mdi-account-edit')
   cli_edit.classList.add('mdi-content-save')
   NnameI = newElement({element:'input',cls:['uk-input','uk-input-small'],attr:[['value',Nname.innerHTML],['oninput','updateValue(this)']]},Nname)
   VnameI = newElement({element:'input',cls:['uk-input','uk-input-small'],attr:[['value',Vname.innerHTML],['oninput','updateValue(this)']]},Vname)
@@ -145,7 +145,7 @@ function editData() {
   LVname.style.height = "40px"
   } else{
     cli_edit.setAttribute('key-title','cli_edit')
-    cli_edit.classList.add('mdi-content-save-edit')
+    cli_edit.classList.add('mdi-account-edit')
     cli_edit.classList.remove('mdi-content-save')
     Nname.innerHTML=NnameI.value;
     Vname.innerHTML=VnameI.value;
@@ -157,10 +157,10 @@ function editData() {
     localStorage.setItem('client_name',`${Nname.innerHTML} ${Vname.innerHTML}`);
     localStorage.setItem('client_forenames',`${Vname.innerHTML}`)
     localStorage.setItem('client_surename',`${Nname.innerHTML}`)
-    document.getElementsByClassName('headliner')[0].innerHTML = `${Nname.innerHTML} ${Vname.innerHTML}`;
+    document.getElementsByClassName('headliner')[0].innerHTML = `${Vname.innerHTML} ${Nname.innerHTML}`;
     document.getElementsByClassName('headliner')[0].removeAttribute('onclick')
     document.getElementsByClassName('headliner')[0].setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${Nname.innerHTML||""} ${Vname.innerHTML||""}','${Vname.innerHTML||""}','${Nname.innerHTML||""}','${Email.innerHTML||""}','${localStorage.getItem('client_fc')}')`)
-    document.getElementById('client').innerHTML = `${Nname.innerHTML} ${Vname.innerHTML}`;
+    document.getElementById('client').innerHTML = `${Vname.innerHTML} ${Nname.innerHTML}`;
     console.log(Email.innerHTML,Vname.innerHTML,Nname.innerHTML);
     session.send(`sql UPDATE clients SET email='${Email.innerHTML}', forename='${Vname.innerHTML}', surname='${Nname.innerHTML}' WHERE client_id=${localStorage.getItem('client_id')}`)
   }
