@@ -27,11 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //const apps_s = "satteldruckanalyse";
 
 //HOCKER
-const hocker = document.getElementById('hip').value || null;
-localStorage.setItem('smartcube',hocker)
-const host_h = `http://${hocker}`;
-const ws_h = `ws://${hocker}/messages`;
-const apps_h = null;
+var ws_h = `ws://${script_setting.smartcube}/messages`;
 
 let con_img = document.getElementById("img_Seatbonemeasurement");
 let link_sitzknochen = document.getElementById("Seatbonemeasurement");
@@ -42,7 +38,9 @@ let side_smartcube = document.getElementById('sitzknochen-menu');
 Inside the function, it checks if the variable `hocker` is not null. If `hocker` is not null, it
 creates a new WebSocket connection using the `ws_h` URL and the protocols "soap" and "wamp". */
 let inter_Seatbonemeasurement = setInterval( () => {
-  if(hocker!=null){
+  console.log(script_setting.smartcube);
+  if(script_setting.smartcube){
+    ws_h = `ws://${script_setting.smartcube}/messages`;
     wsH = new WebSocket(ws_h, ["soap", "wamp"]);
   
     wsH.onopen = (event) =>{
