@@ -25,11 +25,18 @@ const host = location.origin;
 const ws = host.replace("http", "ws");
 const app = "satteldruckanalyse";
 
-const sessionID =
-  localStorage.getItem("session").split(" ")[0] == "restart"
-    ? localStorage.getItem("session").split(" ")[1]
-    : localStorage.getItem("new_session");
-    //console.log(sessionID);
+var sessionID;
+if(localStorage.getItem('session')){
+    if(localStorage.getItem('session').split(" ")[0]=='restart'){
+        sessionID = localStorage.getItem('session').split(" ")[1]
+    } 
+} else {
+    sessionID = localStorage.getItem('new_session')
+}
+
+if(localStorage.getItem('sessionID')){
+    sessionID = localStorage.getItem('sessionID')
+}
 try {
   var sattelanalyse = new WebSocket(`${ws}/apps/${app}`, ["soap", "wamp"]);
 } catch (error) {
@@ -167,6 +174,7 @@ sattelanalyse.onmessage = (e) => {
       sattelanalyse.send(`recording retrieve ${recID[fi]}`);
       fi++;
     }
+    translatejs()
   }
   if (data.wsevent === "appquestions") {
     console.log(data.appquestions);
