@@ -58,11 +58,32 @@ var querys;
 
 var bread=0
 
+var local_sess;
+
+localStorage.removeItem('sessionID')
+
+if(localStorage.getItem('session')){
+  local_sess = localStorage.getItem('session');
+  if(local_sess.split(" ")[0]=='restart'){
+    localStorage.setItem('sessionID',local_sess.split(" ")[1])
+  }
+} else {
+  LinkTo('clients.tcls')
+}
+
+
+document.getElementById('headliner').innerHTML = `${localStorage.getItem('client_forenames')} ${localStorage.getItem('client_surename')}`;
+
+
 
-document.getElementById('headliner').innerHTML = localStorage.getItem('client_name');
 
 // document.getElementById('product1').setAttribute('placeholder',gettrans('sda_marke'))
 
+function SessReload() {
+  localStorage.setItem('session',local_sess);
+  location.reload(true);
+}
+
 /**
  * The function sets the contrast value based on the user's input and saves it in local storage.
  */
@@ -191,6 +212,8 @@ let num;
 
 var ch;
 var cw;
+
+
 /* The above code is getting the height and width of the Frame-3 class. */
 ch = document.getElementsByClassName("Frame-3")[0].offsetHeight;
 cw = document.getElementsByClassName("Frame-3")[0].offsetWidth;
@@ -212,8 +235,8 @@ the code sends a SQL query to the database to update the notes column in the ses
 new value of the textarea. */
 document.getElementById('note_session').onchange = function() {
   //console.log("note_session change");
-  if(localStorage.getItem('session').split(' ')[0] == "restart"){
-    sess = localStorage.getItem('session').split(' ')[1]
+  if(local_sess.split(' ')[0] == "restart"){
+    sess = local_sess.split(' ')[1]
   } else{
     onsqlresult = getSession
     sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
@@ -232,12 +255,17 @@ if($(window).height()>$(window).width()){
 
 /* Checking if the cable is connected or not. If it is not connected, it will show a modal. */
 var conBT = setInterval(function () {
-  if(cable==false){
+  if(cable==false && setting.demo == 'false'){
   connectBt()
   //UIkit.modal($("#modal-connect-with-bluetooth")).show();
   let append = document.getElementsByClassName('navbar-right')[0];
   let li = newElement({element:'li',cls:['nav-item']},append);
   let btn = newElement({element:'button',cls:['uk-button','uk-button-small','uk-button-default','ico-16', 'mdi', 'mdi-connection'],attr:[['onclick','connectBt()'],['key-title','sda_bluetooth_con']]},li)
+  } else {
+    DemoMode()
+    let append = document.getElementsByClassName('navbar-right')[0];
+  let li = newElement({element:'li',cls:['nav-item']},append);
+  let btn = newElement({element:'button',cls:['uk-button','uk-button-small','uk-button-default','ico-16', 'mdi', 'mdi-movie-star'],attr:[['onclick','DemoMode()']]},li)
   }
   clearInterval(conBT);
 }, 1000);
@@ -324,6 +352,12 @@ function save_rec(num) {
   
   //TODO: Dialog nach aktuellem CI erstellen und übersetzen!
   UIkit.notification({message: `${aLangKeys[lang]['save_data']}`})
+
+  let inter = setInterval(()=> {
+      UIkit.notification.closeAll()
+      clearInterval(inter);
+    }, 500);
+
 }
 
 /**
@@ -336,11 +370,11 @@ function load_rec(num) {
   btn.setAttribute('disabled','')
 
   console.log('load ',num);
-  if(localStorage.getItem('session').split(' ')[0]=='restart'){
+  if(local_sess.split(' ')[0]=='restart'){
   onsqlresult = RowImg
-  sattelanalyse.send(`sql select * from recordings WHERE analysis=2 AND session_id=${localStorage.getItem('session').split(' ')[1]}`)
+  sattelanalyse.send(`sql select * from recordings WHERE analysis=2 AND session_id=${local_sess.split(' ')[1]}`)
   }
-  if(localStorage.getItem('session').split(' ')[0]=='start'){
+  if(local_sess.split(' ')[0]=='start'){
    onsqlresult = getSession
    sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
    let getrow = setInterval(function () {
@@ -427,14 +461,14 @@ function run_Sitzknochen(num) {
 }
 
 
-
+//!"beforeunload"
 /* Adding an event listener to the window object. The event listener is listening for the beforeunload
 event. When the event is triggered, the onConfirmRefresh function is called. */
 //window.addEventListener("beforeunload", onConfirmRefresh, { capture: true });
 
 /* The above code is a JavaScript code that is binding two events to the window object. */
 $( window ).bind( 'beforeunload' , ( event ) => {
-  event.preventDefault();
+  //event.preventDefault();
   return '';
 } ).bind( 'unload', ( event ) => {
   sattelanalyse.send('btdisconnect')
@@ -451,10 +485,11 @@ function run_Sattelanalyse() {
       rec_cancel(2);
       sattelanalyse.send('get clientsettings')
       grid_socet('no')
-      if(localStorage.getItem('session').split(' ')[0]=='restart'){
-        sess = localStorage.getItem('session').split(' ')[1]
+      StopDemo()
+      if(local_sess.split(' ')[0]=='restart'){
+        sess = local_sess.split(' ')[1]
       }
-      if(localStorage.getItem('session').split(' ')[0]=='start'){
+      if(local_sess.split(' ')[0]=='start'){
          onsqlresult = getSession
          sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
       }
@@ -495,6 +530,7 @@ function run_Sattelanalyse() {
               setting.line_color ="#ffff00";
               setting.showText = true;
               setting.pelv = 1
+              setting.demo = "false"
               sattelanalyse.send(`set clientsettings ${JSON.stringify(setting)}`)
               for (const key in setting) {
                 const element = setting[key];
@@ -514,6 +550,27 @@ function run_Sattelanalyse() {
           error_msg(data);
         }
 
+        if(data.wsevent === "demostreams"){
+          console.log(data);
+          let demo = document.getElementById('listDemo');
+          demo.innerHTML = "";
+          for (const key in data) {
+            if(key != "wsevent"){
+              console.log(key,data[key]);
+              let ul    = newElement({element:"ul",cls:['uk-list']},demo)
+              let li    = newElement({element:"li"},ul)
+              let label = newElement({element:"label",attr:[['for',key]]},li)
+              let x     = newElement({element:"input",cls:['uk-radio'],id:key,attr:[['type','radio'],['name','demo'],['value',key]]},label)
+              label.innerHTML += data[key]
+            }
+            UIkit.modal($('#modal-demo-mode')).show();
+            
+            //document.getElementsByClassName('nav_menu')[0].style.backgroundColor = "orange"
+            //$("input[type='radio'][name='demo']:checked").val();
+          }
+
+        }
+
         /* The above code is checking if the data.wsevent is equal to "btevent" and if it is, it will check if
         the data.btevent is equal to "error" and if it is, it will hide the modal and display the error
         message. If the data.btevent is equal to "status", it will display the name and address of the
@@ -939,7 +996,13 @@ img3 = `/sattelbild?rnd=${new Date().getTime()}`;
 measure(canvas1);
 measure(canvas2);
 
-
+addEventListener("resize", (event) => {
+  ch = document.getElementsByClassName("Frame-3")[0].offsetHeight;
+  cw = document.getElementsByClassName("Frame-3")[0].offsetWidth;
+  createCanvas(canvas1);
+  createCanvas(canvas2);
+  createCanvas(canvas3);
+});
 
 /**
  * It sends a command to the server to set the background color of the JPEG image
@@ -1651,10 +1714,10 @@ function result_2(jsn) {
  * It reads the values of the three input fields and sends them to the server
  */
 function toProtokol() {
-  if(localStorage.getItem('session').split(' ')[0]=='restart'){
-    sess = localStorage.getItem('session').split(' ')[1]
+  if(local_sess.split(' ')[0]=='restart'){
+    sess = local_sess.split(' ')[1]
   }
-  if(localStorage.getItem('session').split(' ')[0]=='start'){
+  if(local_sess.split(' ')[0]=='start'){
      onsqlresult = getSession
      sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
   }
@@ -1674,10 +1737,10 @@ function toProtokol() {
 }
 
 function toGalerie() {
-  if(localStorage.getItem('session').split(' ')[0]=='restart'){
-    sess = localStorage.getItem('session').split(' ')[1]
+  if(local_sess.split(' ')[0]=='restart'){
+    sess = local_sess.split(' ')[1]
   }
-  if(localStorage.getItem('session').split(' ')[0]=='start'){
+  if(local_sess.split(' ')[0]=='start'){
      onsqlresult = getSession
      sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
   }
@@ -1982,41 +2045,16 @@ function setProduct2(params) {
   localStorage.setItem('product2',JSON.stringify(local))
 }
 
+function DemoMode() {
+  sattelanalyse.send(`demostreams`)
+}
 
-//var imggif = document.getElementById('div_live_img')
+function StartDemo() {
+  sattelanalyse.send(`democonnect ${$("input[type='radio'][name='demo']:checked").val()}`)
+  //document.getElementsByClassName('nav_menu')[0].style.backgroundColor = "orange"
+}
 
-//var gif = new GIF({
-//  workers: 2,
-//  quality: 10,
-//  width: imggif.width,
-//  height: imggif.height,
-//  workerScript: "/production/js/gif.worker.js"
-//});
-
-//gif.on('finished', function(blob) {
-//  window.open(URL.createObjectURL(blob));
-//});
-
-//gif.on('error',(err)=>{
-//  gif.finishRendering()
-//  currentFrame = 0;
-//});
-
-//function createAnimation() {
-//  var frameRate = 6;              // Frames in seconds
-//  var duration = setting.aufZeit;  // dauer in seconds
-//  var currentFrame = 0;
-//  var totalFrames = frameRate * duration;
-  
-  
-//  let interval_gif = setInterval( () => {
-//    if (currentFrame >= totalFrames){
-//      gif.render();
-//      clearInterval(interval_gif);
-//    }
-//    console.log(currentFrame,`fps: ${frameRate}`,`frames total: ${totalFrames}`,`duration: ${duration}`)
-//    imggif.setAttribute("src",`${host}/sattelbild?image=sda_live&rnd=${(new Date).getTime()}`); 
-//    gif.addFrame(imggif);
-//    currentFrame++;
-//  }, 1000 / frameRate)
-//}
\ No newline at end of file
+function StopDemo(){
+  sattelanalyse.send(`demodisconnect`)
+  //document.getElementsByClassName('nav_menu')[0].style.backgroundColor = "var(--secondary-text)"
+}
