@@ -58,7 +58,7 @@ var URL_SmartCube = ""
 var htdocsInfo = new Object();
 
 script_websocket.onopen = (e)=>{
-  console.log('websocket open');
+  console.log('websocket open',e);
   script_websocket.send('get clientsettings')
 }
 
@@ -72,6 +72,14 @@ script_websocket.onmessage = (e)=> {
   if(script_Data.wsevent ==="clientsettings"){
     script_setting = script_Data.clientsettings
     console.log(script_setting);
+    if(script_setting.demo){
+      if(document.getElementById('btn_demo_mode'))
+      document.getElementById('btn_demo_mode').style.color = document.getElementById('btn_demo_mode') && script_setting.demo == 'true' ? 'var(--warn)' : 'unset';
+      document.getElementById('demo_mode').innerHTML = document.getElementById('demo_mode') && script_setting.demo == 'true' ? 'DEMO MODE' : '';
+      if(document.getElementById('switch-demo')&& script_setting.demo == 'true'){
+        document.getElementById('switch-demo').setAttribute('checked','');
+      }
+    }
     if(script_setting.bg){
       back.removeAttribute('class')
       back.classList.add('right_col')
@@ -82,6 +90,10 @@ script_websocket.onmessage = (e)=> {
         document.getElementById('url_smartcube').value = script_setting.smartcube
         localStorage.setItem('smartcube',script_setting.smartcube)
       }
+      if(document.getElementById('hip')){
+        document.getElementById('hip').value = script_setting.smartcube
+        localStorage.setItem('smartcube',script_setting.smartcube)
+      }
     }
     try {
       if(script_setting.UserCompany){
@@ -259,9 +271,9 @@ of the key in the params object. */
  * @param {String}lang - The language you want to translate to.
  */
 function langSelected(lang) {
-  let httplang = new XMLHttpRequest();
+  //let httplang = new XMLHttpRequest();
   let result = lang.substring(0, 2);
-  var url = `/production/setlanguagefile.tcls?systemsprache=${result}`;
+  //var url = `/production/setlanguagefile.tcls?systemsprache=${result}`;
   localStorage.setItem('lang',result)
   fetch("/production/json/lang.json", {
     mode: "no-cors",
@@ -269,8 +281,8 @@ function langSelected(lang) {
     .then((res) => res.json())
     .then((data) => (_Translate(data)));
 
-  httplang.open("GET", url, true);
-  httplang.send();
+  //httplang.open("GET", url, true);
+  //httplang.send();
 }
 
 /**
@@ -285,7 +297,6 @@ function dashboardCards() {
     }) // disable CORS because path does not contain http(s)
     .then((res) => res.json())
     .then((data) => (DashCards(data)));
-    translatejs()
   } catch (error) {
     getError(error)
   }
@@ -345,6 +356,7 @@ function DashCards(jsn){
       }
     }
   }
+  translatejs()
 }
 /**
  * It fetches the JSON file, then calls the _Translate function with the JSON file as an argument.
@@ -454,6 +466,9 @@ function BreadCrumb(params) {
       if(location.pathname == "/production/system.tcls"){
         document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
       }
+      if(location.pathname == "/production/info.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
       s.setAttribute('onclick',`LinkTo('${element}.tcls')`)
       s.setAttribute('style','cursor: pointer')
       s.innerHTML = element;
@@ -473,7 +488,7 @@ function BreadCrumb(params) {
         if(element==='client'){
           let a2 = newElement({element:'a',attr:[['onclick',`LinkTo('${element}.tcls')`],['style','display:none;']]},li)
           a.removeAttribute('key');
-          a.innerHTML = localStorage.getItem('client_name')
+          a.innerHTML = `${localStorage.getItem('client_forenames')} ${localStorage.getItem('client_surename')}`
           a.setAttribute('href',`/production/client.tcls`)
           a.setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${localStorage.getItem('client_name')}','${localStorage.getItem('client_forenames')}','${localStorage.getItem('client_surename')}','${localStorage.getItem('client_mail')||""}','${localStorage.getItem('client_fc')}')`)
           //info(`${localStorage.getItem('client_id')}`,`${localStorage.getItem('client_name')}`,`${localStorage.getItem('client_mail')||""}`,`${localStorage.getItem('client_fc')}`)
@@ -606,9 +621,14 @@ if(location.pathname == "/production/tpfs.tcls"){
 if(location.pathname == "/production/products.tcls"){
   BreadCrumb(['dashboard','tpfs','products'])
 }
+if(location.pathname == "/production/info.tcls"){
+  BreadCrumb(['dashboard','info'])
+}
 
 var checkbox = document.getElementById('basic');
 var checkbox_view = document.getElementById('switch-1')
+if(document.getElementById('switch-demo'))
+var checkbox_demo = document.getElementById('switch-demo')
 var checkbox_mask1 = document.getElementById('mask1')
 var checkbox_mask2 = document.getElementById('mask2')
 var checkbox_set_comp = document.getElementById('set_comp')
@@ -676,6 +696,14 @@ if (this.checked) {
 }
 });
 
+if(document.getElementById('switch-demo')){
+  if(script_setting.demo == 'true'){
+    checkbox_demo.setAttribute('checked','')
+  }
+  checkbox_demo.addEventListener('change',()=>{
+    setDemomode()
+  })
+}
 
 try {
   checkbox_mask1.addEventListener('change', function() {
@@ -805,13 +833,15 @@ using the Date object. It then formats the time into hours, minutes, and seconds
 zeros if necessary. Finally, it updates the innerHTML of an element with the id 'clock' with the
 formatted time. */
 let clock_dash = setInterval(function () {
+  if(aLangKeys[lang]){
   let c = document.getElementById('clock');
   let time = new Date();
   let h = time.getHours() < 10 ? '0' + time.getHours() : time.getHours();
   let m = time.getMinutes() < 10 ? '0' + time.getMinutes() : time.getMinutes();
   let s = time.getSeconds() < 10 ? '0' + time.getSeconds() : time.getSeconds();
-  let time_str = `${aLangKeys[lang][week[time.getDay()]]} ${time.getDate()} ${aLangKeys[lang][month[time.getMonth()]]} ${h}:${m}:${s}`;
+  let time_str = `${aLangKeys[lang][week[time.getDay()||1]]} ${time.getDate()} ${aLangKeys[lang][month[time.getMonth()||1]]} ${h}:${m}:${s}`;
   c.innerHTML = time_str;
+  }
  }, 1000);
 // $(window).resize(function() {
 //   abso();
@@ -1182,6 +1212,8 @@ $(document).ready(function () {
     checkbox_mask1.removeAttribute('checked')
     checkbox_mask2.removeAttribute('checked')
     checkbox_maskedit.removeAttribute('checked')
+    if(script_setting.demo == "true")
+    checkbox_demo.setAttribute('checked','true')
   }
 });
 
@@ -1219,4 +1251,104 @@ function updateValue(e) {
     ele.value = ele.value.replaceAll("'",'')
     UIkit.notification({message: `' ${aLangKeys[lang].not_allowed}`, status: 'warn'})
   }
+}
+
+try {
+  fetch("https://downloads.velometrik.de/version.json")
+  .then((res)=> res.json())
+  .then((data)=> info_update(data))
+} catch (error) {
+  console.error(error);
+}
+
+function info_update(jsn){
+
+  let comp = setInterval(()=> {
+
+    let aV = htdocsInfo.VERSION.replaceAll('.','')
+  if(document.getElementById('dl_info')){
+    var t = document.getElementById('dl_info')
+    var i = 0
+    jsn.versionen.forEach(e => {
+      let nV = e.version.replaceAll('.','')
+      if (aV < nV) {
+        i++
+        t.classList.remove('hidden')
+        if(localStorage.getItem('ReadFirstStart') == "true" && location.pathname == '/production/dashboard.tcls' && i==1){
+          OpenInfoBox(`${e.version}`)
+        } else if (localStorage.getItem('ReadFirstStart') == "false" && location.pathname == '/production/dashboard.tcls'&& i==1){
+          let btn = document.getElementById("firststart_button")
+          btn.setAttribute('onclick',`OpenInfoBox("${e.version}")`)
+        }
+      }
+      return;
+    });
+}
+
+    clearInterval(comp);
+  }, 500);
+
+  
+}
+
+function OpenInfoBox(params){
+  OpenModDialog({type:'neutral',head:aLangKeys[lang]["new_update_head"],title:["new_update_title"],msg:`Version: ${params}`,master_btn:["button_ok","LinkTo('system.tcls')"],slave_btn:["button_cancel"]})
+}
+
+try {
+  fetch("https://downloads.velometrik.de/infos.json")
+  .then((res) => res.json())
+  .then((data) => (DashCards(data)));
+} catch (error) {
+  console.error(error);
+}
+
+function TESTJSN(){
+  let jsn = aLangKeys
+  let keys = []
+  let langs = []
+  
+  jsn.zusatzlang.forEach(element => {
+      langs.push(element.split(' ')[0])
+  });
+
+  for (const key in jsn.de) {
+          keys.push(key)
+  }
+
+  langs.forEach(element => {
+      console.log(element);
+      if(jsn[element]){
+          console.log(element,"exist");
+          let a = {}
+          a[element]={}
+          keys.forEach(element2 => {
+              if(!jsn[element][element2]){
+                  a[element][element2] = element2
+              }
+          });
+          console.error(a);
+      } else {
+          console.error(element,"not exist");
+      }
+  });
+
+  console.log(keys,langs);
+}
+
+function setDemomode() {
+  if(!script_setting.demo){
+    script_setting.demo = "false"
+  }
+  script_setting.demo = script_setting.demo == 'false' ? "true" : "false";
+
+  //document.getElementById('btn_demo_mode').style.color = document.getElementById('btn_demo_mode') && script_setting.demo == 'true' ? 'var(--warn)' : 'unset';
+  
+  document.getElementById('demo_mode').innerHTML = document.getElementById('demo_mode') && script_setting.demo == 'true' ? 'DEMO MODE' : '';
+
+  saveConfig();
+
+  if(location.pathname === "/production/saddle_pressure_analysis.tcls"){
+    SessReload();
+  }
 }
\ No newline at end of file
