@@ -40,6 +40,7 @@ var recID =[];
 
 localStorage.setItem('session',"")
 localStorage.setItem('session_note',"")
+localStorage.removeItem('sessionID')
 /* A variable that is used to store a function that is called when the server sends a message to the
 client. */
 var onsqlresult = getLog;
@@ -57,7 +58,7 @@ session.onopen = (e) => {
         document.getElementById('loader').classList.add('hidden')
         end_session()
         onsqlresult = clients_list;
-        session.send(`sql select * from clients where client_id != 1 order by client_id desc`)
+        session.send(`sql select * from clients order by client_id desc`)
     }
 };
 
@@ -187,7 +188,7 @@ function clients_list(array) {
         tbody.append(tr_body);
         tr_body.innerHTML =  `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.client_id}</td>`
         tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.first_contact}</td>`
-        tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.surname||""} ${x.forename||""}</td>`
+        tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.forename||""} ${x.surname||""}</td>`
         tr_body.innerHTML += `<td onclick="info(${x.client_id},'${x.surname||""} ${x.forename||""}','${x.forename||""}','${x.surname||""}','${x.email||""}','${x.first_contact}')">${x.email||""}</td>`
         // tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small" uk-icon="icon: play" onclick="new_session_id(${x.client_id})" uk-tooltip="Neue Sitzung"></button></td>`
          tr_body.innerHTML += `<td><button class="uk-button uk-button-default uk-button-small adba basicview ico-16 mdi mdi-trash-can-outline" onclick="ClientDel(${x.client_id})"></button></td>`
@@ -357,7 +358,7 @@ function new_session_id(id){
 function suche(params) {
     $('.suche').each(element => {
         $('.suche')[element].classList.add('hide')
-        if($('.suche')[element].getAttribute('suche').includes(params))
+        if($('.suche')[element].getAttribute('suche').includes(params)|| $('.suche')[element].getAttribute('suche').toLowerCase().includes(params))
         $('.suche')[element].classList.remove('hide')
     });
 }
\ No newline at end of file
