@@ -9,9 +9,10 @@
 # Historie:
 # ??.06.2019 Siegmar Müller Testversion fertiggestellt
 # 05.05.2022 Siegmar Müller vmkstationd3 begonnen
+# 01.11.2023 Siegmar Müller V 3.2 begonnen
 #
 
-set VERSION "3.1.0_U"
+set VERSION "3.2.0_U"
 
 set ::dir [file dirname [info script]]
 if {[string equal -length 1 $::dir "."]} {
@@ -34,12 +35,13 @@ set CONF_LOGLEVEL notice
 if {[string index $VERSION end] in {A U}} {; # Alpha oder unfertige Version
     set CONF_LOGLEVEL debug
 }
-set PIEPSER 0; # Wird nach erfolgreicher Initialisierung 1
+set ::PIEPSER 0; # Piepserplatine ist vorhanden (Wird nach erfolgreicher Initialisierung 1)
 # Folgendes wird von der Initialisierung überschrieben:
 set BGCOLOR #404040
 set COLORCONTRAST 0
 set JPEGOPTIONS [list -quality 60 -res 12 -grid no -frame 0]
 set WS_URL "https://ws-1-1.velometrik.de/vmkservice"
+set WS_VERSION ""; # wird beim Webservice abgefragt
 set STATION_NR 0; # Nicht registrierte Station. Das wird bei der Registierung  überschrieben.
 set using_defaults 1
 
@@ -60,7 +62,7 @@ set ::PORTALSERVER "" ; # Wird vom Webservice geliefert
 # (siehe auch setup/vmkstationd.conf)
 array set ::LEDFARBEN [list SCHWARZ 0 GRUEN 1 BLAU 2 HELLBLAU 3 ROT 4 GELBGRUEN 5 VIOLETT 6 WEISS 7]
 # LAN beinhaltet WLAN
-set ::STATUSLEVELS [list OFF POWER MATTE LAN INET WEBSERVICE ANGEMELDET]
+set ::STATUSLEVELS [list OFF POWER LAN INET WEBSERVICE ANGEMELDET MATTE]
 array set ::STATUSFARBEN [list OFF SCHWARZ POWER ROT MATTE VIOLETT LAN BLAU INET HELLBLAU WEBSERVICE GRUEN ANGEMELDET WEISS]
 # Der aktuelle Stationsstatus (OFF darf niemals 0 sein)
 array set ::stationsstatus [list OFF 1 POWER 0 MATTE 0 LAN 0 INET 0 WEBSERVICE 0 ANGEMELDET 0]
@@ -89,6 +91,45 @@ if {[file exists /usr/local/etc/vmkstationd.conf]} {
 }
 #}}} Konfiguration holen
 
+#{{{ Velobox Konfiguration
+namespace eval VELOBOX_CONF {
+    # Die erwarteten Variablen mit ihren Vorgaben
+    set VERSION "0.0"
+    set LANG "en"
+    # vlbupdate
+    set DOWNLOADSERVER ""
+    set UPDATEDIR ""
+    # List of additional hardware components
+    # e.g.: HARDWARE=PIEPSER,JIT35
+    set HARDWARE ""
+    # Usage of this velobox
+    # e.g. USAGE=
+    set USAGE "bikefitting"
+    # Implementation for USAGE
+    # e.g. IMPLEMENTATION=velometrik
+    set IMPLEMENTATION ""
+
+    # Velobox Konfiguration einlesen
+    # @param filename   Dateiname der Konfiguration
+    proc readVeloboxConf {filename} {
+        catch {
+            set fd [open $filename "r"]
+            while {[gets $fd line] >= 0} {
+                if {[regexp {^[[:space:]]*([A-Za-z0-9]+)[[:space:]]*=[[:space:]]*([^[:space:]#]*)} $line match name value]} {
+                    set [namespace current]::$name "$value"
+                }
+            }
+            close $fd
+        }
+    }; # proc readVeloboxConf 
+
+    # Tatsächliche Werte, sofern vorhanden, einlesen
+    if {[file exists /usr/local/etc/velobox.conf]} {
+        readVeloboxConf /usr/local/etc/velobox.conf
+    }
+}
+#}}} Velobox Konfiguration
+
 # Hilfe ausgeben und beenden
 proc help {} {; #{{{
     puts ""
@@ -293,8 +334,11 @@ proc tracecommand {command op} {
 ##################################################################################################
 
 # Status setzen/zurücksetzen
-#TODO Unklar: Welche Bedeutung hat die Sattelmatte für den Stationsstatus?
-#TODO Dok fertig
+# Schaltet den angegebenen Status ein oder aus
+# und bringt anschließend den höchsten Statuslevel zur Anzeige,
+# für den alle Vorgängerlevels eingeschaltet sind.
+# @param statusname s. ::STATUSLEVELS
+# @param on_off     0 oder 1
 proc setStationsstatus {statusname {on_off 1}} {; #{{{
     set i_status [lsearch $::STATUSLEVELS $statusname]
     if {$i_status < 0} {; # interner Fehler
@@ -313,36 +357,25 @@ proc setStationsstatus {statusname {on_off 1}} {; #{{{
     if {$::PIEPSER} {
         ::piepser::setLED $::LEDFARBEN($::STATUSFARBEN($status_neu))
     }
-    #TODO Statusänderung über Websocket verteilen
+    #TODO Statusänderung über Websocket verteilen => wsdomain einrichten
     srvLog {setStationsstatus} Notice "Stationsstatus: $status_neu"
     #}}}
-}; # proc setStatus 
+}; # proc setStationsstatus 
 
 
 # Piepser mit LEDs initialisieren
 #TODO Das kommt in ein noch zu erstellendes Kernelmodul in lib/kernel
 # Das scheitert, wenn es nicht auf einem Raspi ausgeführt wird.
-# Es scheitert auch, wenn es nicht von root ausgeführt wird => TODO $::USER == root testen
+# Es scheitert nicht, wenn es auf einem Raspi ohne Piepserplatine ausgeführt wird.
 if {[catch {::piepser::gpioSetup} msg]} {
-    srvLog gpioSetup Error "$msg"
+    srvLog gpioSetup Warn "Der Piepser wurde nicht aktiviert: $msg"
 } else {
-    set PIEPSER 1
+    set ::PIEPSER 1
     srvLog gpioSetup Notice "Piepser initialisiert"
     setStationsstatus POWER
 }
 
 
-# Beendete Messung signalisieren
-#TODO Das kommt in ein noch zu erstellendes Kernelmodul in lib/kernel
-proc signalFinished {} {
-    if {$::PIEPSER} {
-        # Ein Fehler an dieser Stelle ist unproblematisch,
-        # darf aber die Weitergabe der Meßergebnisse nicht blockieren.
-        catch {::piepser::toogleGpioValue $::piepser::BUZZER {100 100 800 2000}}
-    }
-}; # proc signalFinished 
-
-
 #TODO Konfigurierbar:
 set ::WSServer::HTTPD(default) "index.tcls"
 
@@ -501,28 +534,37 @@ namespace eval ::wscomm {; #{{{
                 set internet_verfuegbar 1
                 setStationsstatus INET
                 # Antwortet der Webservice ?
-                # (Bei der Gelegenheit setzen wir gleich die IPadresse.)
-                if {[execWsRequest set [list station_nr $::STATION_NR what local_ip value $local_ip] wsAntwort]} {
-                    srvLog {inetcheck} Debug "Webservice antwortet auf /set local_ip mit \"$wsAntwort\"."
-                    if {[regexp {^{.*}$} $wsAntwort]} {; # JSON-Antwort
-                        set dictWsAntwort [::json::json2dict $wsAntwort]
-                        if {[dict exists $dictWsAntwort portalserver]} {
-                            set ::PORTALSERVER [dict get $dictWsAntwort portalserver]
-                            srvLog {inetcheck} Notice "Portalserver ist $::PORTALSERVER."
-                            setStationsstatus ANGEMELDET
-                        } else {
-                            srvLog {inetcheck} Warn "Webservice meldet keinen Portalserver."
-                            setStationsstatus ANGEMELDET 0
+                if {[execWsRequest ping {} wsAntwort]} {; # Er antwortet
+                    srvLog {inetcheck} Debug "Webservice antwortet auf /ping mit \"$wsAntwort\"."
+                    # Webservice Version festhalten
+                    set dictWsAntwort [::json::json2dict $wsAntwort]
+                    if {[dict exists $dictWsAntwort version]} {
+                        set ::WS_VERSION [dict get $dictWsAntwort version]
+                        srvLog {inetcheck} Notice "Webservice ${::WS_URL} hat die Version ${::WS_VERSION}."
+                    }
+                    # (Bei der Gelegenheit setzen wir gleich die IPadresse.)
+                    if {[execWsRequest set [list station_nr $::STATION_NR what local_ip value $local_ip] wsAntwort]} {
+                        srvLog {inetcheck} Debug "Webservice antwortet auf /set local_ip mit \"$wsAntwort\"."
+                        if {[regexp {^{.*}$} $wsAntwort]} {; # JSON-Antwort
+                            set dictWsAntwort [::json::json2dict $wsAntwort]
+                            if {[dict exists $dictWsAntwort portalserver]} {
+                                set ::PORTALSERVER [dict get $dictWsAntwort portalserver]
+                                srvLog {inetcheck} Notice "Portalserver ist $::PORTALSERVER."
+                                setStationsstatus ANGEMELDET
+                            } else {
+                                srvLog {inetcheck} Warn "Webservice meldet keinen Portalserver."
+                                setStationsstatus ANGEMELDET 0
+                            }
                         }
                     }
                     set webservice_verfuegbar 1
                     setStationsstatus WEBSERVICE
-                } else {
+                } else {; # Webservice antwortet nicht
                     srvLog {inetcheck} Warn "Webservice nicht verfügbar"
                     set webservice_verfuegbar 0
                     setStationsstatus WEBSERVICE 0
                 }
-            } else {; # Keine Antwort auf ping
+            } else {; # Keine Antwort auf ping 8.8.8.8
                 srvLog {inetcheck} Warn "Kein Internetzugang"
                 set internet_verfuegbar 0
                 setStationsstatus INET 0
